@@ -13,10 +13,10 @@ pub fn derive_layer(input: TokenStream) -> TokenStream {
         _ => panic!("Only enums can automatically derive Layer"),
     };
 
-    assert!(variants.len() <= 16, "Reached the maximum of 16 layers");
+    assert!(variants.len() <= 32, "Reached the maximum of 32 layers");
 
     let to_bits = variants.iter().enumerate().map(|(index, variant)| {
-        let bits: u16 = 1 << index;
+        let bits: u32 = 1 << index;
         assert!(
             variant.fields.is_empty(),
             "Can only derive Layer for enums without fields"
@@ -25,19 +25,19 @@ pub fn derive_layer(input: TokenStream) -> TokenStream {
         quote! { #enum_ident::#ident => #bits, }
     });
 
-    let all_bits: u16 = if variants.len() == 16 {
-        0xffff
+    let all_bits: u32 = if variants.len() == 32 {
+        0xffffffff
     } else {
         (1 << variants.len()) - 1
     };
 
     let expanded = quote! {
         impl heron::PhysicsLayer for #enum_ident {
-            fn all_bits() -> u16 {
+            fn all_bits() -> u32 {
                 #all_bits
             }
 
-            fn to_bits(&self) -> u16 {
+            fn to_bits(&self) -> u32 {
                 match self {
                     #(#to_bits)*
                 }
